==> xdvik-22.76.1.tar.gz: xdvik-22.76.1/texk/xdvik/translations.h <==
/* key translations */
#include "c-auto.h"
#include "xdvi.h"

static _Xconst char base_key_translations[] =
/* note: more specific key bindings must always come first
   (i.e. `alt ctrl' before `ctrl' before unmodified)
   `:' means that case matters
*/
    ":Alt Ctrl<Key>+:	change-density(10)\n"
    ":Alt Ctrl<Key>-:	change-density(-10)\n"
    ":Ctrl<Key>+:	set-shrink-factor(+)\n"
    ":Ctrl<Key>-:	set-shrink-factor(-)\n"
    ":<Key>-:		minus()\n"
    ":<Key>?:		help()\n"
    ":<Key>>:		goto-page()\n"
    ":<Key><:		goto-page(1)\n"
    ":<Key>^:		home()\n"
    "<Key>space:	unpause-or-next()\n"
#ifdef HTEX
    ":<Key>B:		htex-back()\n"
#endif
    ":<Key>b:		back-page()\n"
    ":Ctrl<Key>c:	quit()\n"
#if COLOR
    ":<Key>C:		set-color()\n"
#endif
    ":<Key>c:		center()\n"
    ":Ctrl<Key>d:	quit()\n"
    ":<Key>d:		down()\n"
    "Ctrl<Key>f:	select-dvi-file()\n"
#ifdef HTEX
    ":<Key>F:		htex-forward()\n"
#endif
    ":<Key>f:		forward-page()\n"
#ifdef GREY
    ":<Key>G:		set-greyscaling()\n"
#endif
    ":<Key>g:		goto-page()\n"
    "Ctrl<Key>h:	back-page()\n"
    ":<Key>h:		help()\n"
#ifdef HTEX
    ":<Key>i:		htex-anchorinfo()\n"
#endif
    "Ctrl<Key>j:	forward-page()\n"
    ":<Key>k:		set-keep-flag()\n"
    "Ctrl<Key>l:	fullscreen()\n"
    ":<Key>l:		left()\n"
    "Ctrl<Key>m:	ruler-mode()\n"
    ":<Key>M:		set-margins()\n"
    ":<Key>m:		toggle-mark()\n"
    "Ctrl<Key>n:	toggle-mark()forward-page()\n"
    ":<Key>n:		forward-page()\n"
    ":<Key>o:		ruler-snap-origin()\n"
    /* this used to be show-display-attributes() - use the output of `-debug PK' instead */
    "Ctrl<Key>p:	print()\n"
    ":<Key>P:		declare-page-number()\n"
    ":<Key>p:		back-page()\n"
    ":<Key>q:		quit()\n"
    "Ctrl<Key>r:	forward-page(0)\n" /* redraw page */
    ":<Key>R:		reread-dvi-file()\n"
    ":<Key>r:		right()\n"
/* not implemented yet:    "Ctrl<Key>s:	search()\n" */
    ":<Key>S:		set-density()\n"
    ":<Key>s:		set-shrink-factor()\n"
    ":<Key>T:		use-tex-pages(toggle)\n"
    ":<Key>t:		switch-magnifier-units()\n"
    "Ctrl<Key>u:	back-page()toggle-mark()\n"
    ":<Key>u:		up()\n"
    "Ctrl<Key>v:	show-source-specials()\n"
#ifdef PS_GS
    ":<Key>V:		set-gs-alpha()\n"
#endif /* PS_GS */
#ifdef PS
    ":<Key>v:		set-ps()\n"
#endif
    "Ctrl<Key>x:	source-what-special()\n"
#if defined(BUTTONS)
    ":<Key>x:		set-expert-mode()\n"
#endif
#ifdef VMS
    "Ctrl<Key>z:	quit()\n"
#endif
    "<Key>Return:	forward-page()\n"
    "<Key>Delete:	up-or-previous()\n"
    "<Key>BackSpace:	back-page()\n"
#ifdef MOTIF
    "<Key>osfDelete:	up-or-previous()\n"
    "<Key>osfBackSpace:	back-page()\n"
#endif
#ifdef MOTIF
    "<Key>osfBeginLine:	home()\n"
    "<Key>osfLeft:	left(0.015)\n"
    "<Key>osfUp:	up(0.015)\n"
    "<Key>osfRight:	right(0.015)\n"
    "<Key>osfDown:	down(0.015)\n"
    "<Key>osfPageUp:	back-page()\n"
    "<Key>osfPageDown:	forward-page()\n"
    "<Key>osfCancel:	discard-number()\n"
#else
    "<Key>Home:		home()\n"
    "<Key>Left:		left(0.015)\n"
    "<Key>Up:		up(0.015)\n"
    "<Key>Right:	right(0.015)\n"
    "<Key>Down:		down(0.015)\n"
    "<Key>Prior:	back-page()\n"
    "<Key>Next:		forward-page()\n"
    "<Key>Escape:	discard-number()\n"
#endif
#ifdef XK_KP_Left
    "<Key>KP_Home:	home()\n"
    "<Key>KP_Left:	left()\n"
    "<Key>KP_Up:	up()\n"
    "<Key>KP_Right:	right()\n"
    "<Key>KP_Down:	down()\n"
    "<Key>KP_Prior:	back-page()\n"
    "<Key>KP_Next:	forward-page()\n"
    "<Key>KP_Delete:	up-or-previous()\n"
    "<Key>KP_Enter:	forward-page()\n"
#endif
    "";


static _Xconst char base_mouse_translations[] =
    "Shift<Btn1Down>:	drag(+)\n"
    "Shift<Btn2Down>:	drag(|)\n"
    "Shift<Btn3Down>:	drag(-)\n"
    "Ctrl<Btn1Down>:	source-special()\n"
    "<Btn1Down>:	do-href()magnifier(*1)\n"
    "<Btn2Down>:	do-href-newwindow()magnifier(*2)\n"
    "<Btn3Down>:	magnifier(*3)\n"
    "<Btn4Down>:	magnifier(*4)\n"
    "<Btn5Down>:	magnifier(*5)\n"
    "";


/* TODO:
   - describe this in manpage
   - use in the Motif version as well
*/
static _Xconst char default_menu_config[] =
/*  menu:	submenu:		accelerator:	action */
# ifdef SELFILE
    "File:	Open ...:		Ctrl-F:	select-dvi-file()\n"
# endif
    "File:	Reload:			R:	reread-dvi-file()\n"
    "File:	Save ...:		Ctrl-S:	save()\n"
    "File:	Print ...:		Ctrl-P:	print()\n"
    "File:	Quit:			q:	quit()\n"
    "Navigate:	First:			1 g:	goto-page(1)\n"
    "Navigate:	Page-10:		10 p:	back-page(10)\n"
    "Navigate:	Page-5:			5 p:	back-page(10)\n"
    "Navigate:	Prev:			p:	back-page(1)\n"
    "Navigate:	SEP\n"
    "Navigate:	Next:			n:	forward-page(1)\n"
    "Navigate:	Page+5:			5 n:	forward-page(5)\n"
    "Navigate:	Page+10:		10 n:	forward-page(10)\n"
    "Navigate:	Last:			g:	goto-page()\n"
    "Navigate:	SEP\n"
# ifdef HTEX
    "Navigate:	Back Hyperlink:		B:	htex-back()\n"
    "Navigate:	Forward Hyperlink:	F:	htex-forward()\n"
# endif
    "Zoom:	Zoom In:		Ctrl-+:	set-shrink-factor(+)\n"
    "Zoom:	Zoom Out:		Ctrl--:	set-shrink-factor(-)\n"
    "Zoom:	SEP\n"
/*      "Zoom:Full size (1 s):set-shrink-factor(1)\n" */
    "Zoom:	Fit in Window:		s:	set-shrink-factor(a)\n"
    "Zoom:	SEP\n"
    "Zoom:	$#:			1 s:	set-shrink-factor(1)\n"
    "Zoom:	$#:			2 s:	set-shrink-factor(2)\n"
    "Zoom:	$#:			3 s:	set-shrink-factor(3)\n"
    "Zoom:	$#:			4 s:	set-shrink-factor(4)\n"
    "Zoom:	$#:			5 s:	set-shrink-factor(5)\n"
    "Zoom:	$#:			6 s:	set-shrink-factor(6)\n"
    "Zoom:	$#:			7 s:	set-shrink-factor(7)\n"
    "Zoom:	$#:			8 s:	set-shrink-factor(8)\n"
    "Zoom:	$#:			9 s:	set-shrink-factor(9)\n"
/*     "Zoom:$%%:shrink-to-dpi(150)\n" */
/*     "Zoom:$%%:shrink-to-dpi(100)\n" */
/*     "Zoom:$%%:shrink-to-dpi(50)\n" */
    "Mark:	Mark All Pages:			-1 m:	toggle-mark(-1)\n"
    "Mark:	Unmark All Pages:		0 m:	toggle-mark(0)\n"
    "Mark:	SEP\n"
    "Mark:	Toggle Odd Pages:		1 m:	toggle-mark(1)\n"
    "Mark:	Toggle Even Pages:		2 m:	toggle-mark(2)\n"
    "Mark:	Toggle Current Page:		m:	toggle-mark()\n"
# if PS
    "Options:	Show PS:			1 v:	set-ps(1)\n"
    "Options:	Show PS and Bounding Boxes:	2 v:	set-ps(2)\n"
    "Options:	Show Bounding Boxes Only:	0 v:	set-ps(0)\n"
    "Options:	SEP\n"
    "Options:	Use PS Anti-Aliasing:		0 v:	set-gs-alpha(toggle)\n"
    "Options:	SEP\n"
    "Options:	Ruler Mode:			Ctrl-m:	ruler-mode(toggle)\n"
# endif
/*     "Options:Keep position:set-keep-flag(1)\n" */
/*     "Options:Don't keep position:set-keep-flag(0)\n" */
    "Options:	Keep Position:			k:	set-keep-flag(toggle)\n"
    "Options:	Use TeX Pages:			T:	use-tex-pages(toggle)\n"
/* hmm, this probably is better kept in a `preferences' window: */
/*     "Options:SEP\n" */
/*     "Options:Show statusline:1 x:set-expert-mode(1)\n" */
    "Options:	SEP\n"
    "Options:	Fonts Darker:		Alt-Ctrl-+:	change-density(25)\n"
    "Options:	Fonts Lighter:		Alt-Ctrl--:	change-density(-25)\n"
    "Help:	Introduction ...:	:		help(Introduction)\n"
    "Help:	Page Motion ...:	:		help(Page Motion)\n"
    "Help:	Other Commands ...:	:		help(Other Commands)\n"
    "Help:	Mouse Buttons ...:	:		help(Mouse Buttons)\n"
    "Help:	Hyperlinks ...:		:		help(Hyperlinks)\n"
    "Help:	Printing and Saving ...::		help(Printing and Saving)\n"
    "Help:	Source Specials ...:	:		help(Source Specials)\n"
    "Help:SEP\n"
    "Help:	New features in this version::	load-url(http\\://sourceforge.net/project/shownotes.php?release_id=168307)\n"
    "Help:	Send a Bug Report:	:		load-url(http\\://sourceforge.net/tracker/?func=add&group_id=23164&atid=377580)\n"
    "";


static _Xconst char default_toolbar_translations[] =
/*  index	statusline-text					tooltip		action */
    "SPACER(5)\n"
    "0:	Open a new document   (Key\\: Ctrl-F):			Open file:	select-dvi-file()\n"
    "SPACER(10)\n"
    "1:	Reread this document   (Key\\: R):			Reread file:	reread-dvi-file()\n"
    "SPACER(10)\n"
    "2:	Go to the first page of this document   (Key\\: 1g):	First page:	goto-page(1)\n"
    "3:	Go to the previous page of this document   (Key\\: p):	Previous page:	back-page(1)\n"
    "4:	Go to the next page of this document   (Key\\: n):	Next page:	forward-page(1)\n"
    "5:	Go to the last page of this document   (Key\\: g):	Last page:	goto-page(e)\n"
    "SPACER(10)\n"
    "6:	Enlarge the display   (Key\\: Ctrl-+):		Zoom in:		set-shrink-factor(+)\n"
    "7:	Shrink the display   (Key\\: Ctrl--):		Zoom out:		set-shrink-factor(-)\n"
    "SPACER(10)\n"
    "8:	Back to previous link in history   (Key\\: B):	Back hyperlink:		htex-back()\n"
    "9:	Forward to next link in history   (Key\\: F):	Forward hyperlink:	htex-forward()\n"
    "SPACER(10)\n"
    "11:Print this document:Print:print()\n"
    "SPACER(10)\n"
    "12:Toggle marks of odd pages   (Key\\: 1m):	Toggle odd pages:	toggle-mark(1)\n"
    "13:Toggle marks of even pages   (Key\\: 2m):	Toggle even pages:	toggle-mark(2)\n"
    "14:Toggle mark of current page   (Key\\: 2m):	Toggle current page:	toggle-mark()\n"
    "15:Unmark all pages   (Key\\: 0m):			Unmark all pages:	toggle-mark(0)\n"
    "SPACER(10)\n"
    "19:Display fonts darker   (Key\\: Alt-Ctrl-+):	Fonts darker:		change-density(5)\n"
    "20:Display fonts lighter   (Key\\: Alt-Ctrl--):	Fonts lighter:		change-density(-5)\n"
    "";

==> xdvik-22.77.1.tar.gz: xdvik-22.77.1/texk/xdvik/translations.h <==
/* key translations */
#include "c-auto.h"
#include "xdvi.h"
#include "version.h"

static _Xconst char base_key_translations[] =
/* note: more specific key bindings must always come first
   (i.e. `alt ctrl' before `ctrl' before unmodified)
   `:' at start of description means that case matters
*/
    ":Alt Ctrl<Key>+:	change-density(10)\n"
    ":Alt Ctrl<Key>-:	change-density(-10)\n"
    ":Ctrl<Key>+:	set-shrink-factor(+)\n"
    ":Ctrl<Key>-:	set-shrink-factor(-)\n"
    ":<Key>-:		minus()\n"
    ":<Key>?:		help()\n"
    ":<Key>>:		goto-page()\n"
    ":<Key><:		goto-page(1)\n"
    ":<Key>^:		home()\n"
    "<Key>space:	unpause-or-next()\n"
#ifdef HTEX
    ":<Key>B:		htex-back()\n"
#endif
    ":<Key>b:		back-page()\n"
/* removed, redundant and gets in the way
    ":Ctrl<Key>c:	quit()\n" */
#if COLOR
    ":<Key>C:		set-color()\n"
#endif
    ":<Key>c:		center()\n"
/* removed, redundant and gets in the way
    ":Ctrl<Key>d:	quit()\n" */
    ":<Key>d:		down()\n"
    ":Ctrl<Key>f:	select-dvi-file()\n"
#ifdef HTEX
    ":<Key>F:		htex-forward()\n"
#endif
    ":~Alt<Key>f:	forward-page()\n"
#ifdef GREY
    ":<Key>G:		set-greyscaling()\n"
#endif
    ":<Key>g:		goto-page()\n"
    "Ctrl<Key>h:	back-page()\n"
    ":<Key>h:		help()\n"
#ifdef HTEX
    ":<Key>i:		htex-anchorinfo()\n"
#endif
    "Ctrl<Key>j:	forward-page()\n"
    ":<Key>k:		set-keep-flag()\n"
    "Ctrl<Key>l:	fullscreen()\n"
    ":<Key>l:		left()\n"
    "Ctrl<Key>m:	ruler-mode()\n"
    ":<Key>M:		set-margins()\n"
    ":~Alt<Key>m:	toggle-mark()\n"
    "Ctrl<Key>n:	toggle-mark()forward-page()\n"
    ":~Alt<Key>n:	forward-page()\n"
/*     "Ctrl<Key>o:	select-dvi-file()\n" */
    ":~Alt<Key>o:	ruler-snap-origin()\n"
    /* this used to be show-display-attributes() - use the output of `-debug PK' instead */
    "Ctrl<Key>p:	print()\n"
    ":<Key>P:		declare-page-number()\n"
    ":<Key>p:		back-page()\n"
    ":<Key>q:		quit()\n"
    "Ctrl<Key>r:	forward-page(0)\n" /* redraw page */
    ":<Key>R:		reread-dvi-file()\n"
    ":<Key>r:		right()\n"
    "Ctrl<Key>s:	save()\n"
    ":<Key>S:		set-density()\n"
    ":<Key>s:		set-shrink-factor()\n"
    ":<Key>T:		use-tex-pages(toggle)\n"
    ":<Key>t:		switch-magnifier-units()\n"
    "Ctrl<Key>u:	back-page()toggle-mark()\n"
    ":<Key>u:		up()\n"
    "Ctrl<Key>v:	show-source-specials()\n"
#ifdef PS_GS
    ":<Key>V:		set-gs-alpha()\n"
#endif /* PS_GS */
#ifdef PS
    ":<Key>v:		set-ps()\n"
#endif
    "Ctrl<Key>x:	source-what-special()\n"
#if defined(BUTTONS)
    ":<Key>x:		set-expert-mode()\n"
#endif
#ifdef VMS
    "Ctrl<Key>z:	quit()\n"
#endif
    "<Key>Return:	forward-page()\n"
    "<Key>Delete:	up-or-previous()\n"
    "<Key>BackSpace:	back-page()\n"
#ifdef MOTIF
    "<Key>osfDelete:	up-or-previous()\n"
    "<Key>osfBackSpace:	back-page()\n"
#endif
#ifdef MOTIF
    "<Key>osfBeginLine:	home()\n"
    "<Key>osfLeft:	left(0.015)\n"
    "<Key>osfUp:	up(0.015)\n"
    "<Key>osfRight:	right(0.015)\n"
    "<Key>osfDown:	down(0.015)\n"
    "<Key>osfPageUp:	back-page()\n"
    "<Key>osfPageDown:	forward-page()\n"
    "<Key>osfCancel:	discard-number()\n"
#else
    "<Key>Home:		home()\n"
    "<Key>Left:		left(0.015)\n"
    "<Key>Up:		up(0.015)\n"
    "<Key>Right:	right(0.015)\n"
    "<Key>Down:		down(0.015)\n"
    "<Key>Prior:	back-page()\n"
    "<Key>Next:		forward-page()\n"
    "<Key>Escape:	discard-number()\n"
#endif
#ifdef XK_KP_Left
    "<Key>KP_Home:	home()\n"
    "<Key>KP_Left:	left()\n"
    "<Key>KP_Up:	up()\n"
    "<Key>KP_Right:	right()\n"
    "<Key>KP_Down:	down()\n"
    "<Key>KP_Prior:	back-page()\n"
    "<Key>KP_Next:	forward-page()\n"
    "<Key>KP_Delete:	up-or-previous()\n"
    "<Key>KP_Enter:	forward-page()\n"
#endif
    "";


static _Xconst char base_mouse_translations[] =
    "Shift<Btn1Down>:	drag(+)\n"
    "Shift<Btn2Down>:	drag(|)\n"
    "Shift<Btn3Down>:	drag(-)\n"
    "Ctrl<Btn1Down>:	source-special()\n"
    "<Btn1Down>:	do-href()magnifier(*1)\n"
    "<Btn2Down>:	do-href-newwindow()magnifier(*2)\n"
    "<Btn3Down>:	magnifier(*3)\n"
    "<Btn4Down>:	magnifier(*4)\n"
    "<Btn5Down>:	magnifier(*5)\n"
    "";


/* TODO:
   - describe this in manpage
   - use in the Motif version as well
*/
static _Xconst char default_menu_config[] =
/*  menu:	submenu:		accelerator:	action */
# ifdef SELFILE
    "File:	Open ...:		Ctrl-f:	select-dvi-file()\n"
# endif
    "File:	Reload:			R:	reread-dvi-file()\n"
    "File:	Save ...:		Ctrl-s:	save()\n"
    "File:	Print ...:		Ctrl-p:	print()\n"
    "File:	Quit:			q:	quit()\n"
    "Navigate:	First:			1 g:	goto-page(1)\n"
    "Navigate:	Page-10:		10 p:	back-page(10)\n"
    "Navigate:	Page-5:			5 p:	back-page(10)\n"
    "Navigate:	Prev:			p:	back-page(1)\n"
    "Navigate:	SEP\n"
    "Navigate:	Next:			n:	forward-page(1)\n"
    "Navigate:	Page+5:			5 n:	forward-page(5)\n"
    "Navigate:	Page+10:		10 n:	forward-page(10)\n"
    "Navigate:	Last:			g:	goto-page()\n"
    "Navigate:	SEP\n"
# ifdef HTEX
    "Navigate:	Back Hyperlink:		B:	htex-back()\n"
    "Navigate:	Forward Hyperlink:	F:	htex-forward()\n"
# endif
    "Zoom:	Zoom In:		Ctrl-+:	set-shrink-factor(+)\n"
    "Zoom:	Zoom Out:		Ctrl--:	set-shrink-factor(-)\n"
    "Zoom:	SEP\n"
/*      "Zoom:Full size (1 s):set-shrink-factor(1)\n" */
    "Zoom:	Fit in Window:		s:	set-shrink-factor(a)\n"
    "Zoom:	SEP\n"
    "Zoom:	$#:			1 s:	set-shrink-factor(1)\n"
    "Zoom:	$#:			2 s:	set-shrink-factor(2)\n"
    "Zoom:	$#:			3 s:	set-shrink-factor(3)\n"
    "Zoom:	$#:			4 s:	set-shrink-factor(4)\n"
    "Zoom:	$#:			5 s:	set-shrink-factor(5)\n"
    "Zoom:	$#:			6 s:	set-shrink-factor(6)\n"
    "Zoom:	$#:			7 s:	set-shrink-factor(7)\n"
    "Zoom:	$#:			8 s:	set-shrink-factor(8)\n"
    "Zoom:	$#:			9 s:	set-shrink-factor(9)\n"
/*     "Zoom:$%%:shrink-to-dpi(150)\n" */
/*     "Zoom:$%%:shrink-to-dpi(100)\n" */
/*     "Zoom:$%%:shrink-to-dpi(50)\n" */
    "Mark:	Mark All Pages:			-1 m:	toggle-mark(-1)\n"
    "Mark:	Unmark All Pages:		0 m:	toggle-mark(0)\n"
    "Mark:	SEP\n"
    "Mark:	Toggle Odd Pages:		1 m:	toggle-mark(1)\n"
    "Mark:	Toggle Even Pages:		2 m:	toggle-mark(2)\n"
    "Mark:	Toggle Current Page:		m:	toggle-mark()\n"
# if PS
    "Options:	Show PS:			1 v:	set-ps(1)\n"
    "Options:	Show PS and Bounding Boxes:	2 v:	set-ps(2)\n"
    "Options:	Show Bounding Boxes Only:	0 v:	set-ps(0)\n"
    "Options:	SEP\n"
    "Options:	Use PS Anti-Aliasing:		0 v:	set-gs-alpha(toggle)\n"
    "Options:	SEP\n"
    "Options:	Ruler Mode:			Ctrl-m:	ruler-mode(toggle)\n"
# endif
/*     "Options:Keep position:set-keep-flag(1)\n" */
/*     "Options:Don't keep position:set-keep-flag(0)\n" */
    "Options:	Keep Position:			k:	set-keep-flag(toggle)\n"
    "Options:	Use TeX Pages:			T:	use-tex-pages(toggle)\n"
/* hmm, this probably is better kept in a `preferences' window: */
/*     "Options:SEP\n" */
/*     "Options:Show statusline:1 x:set-expert-mode(1)\n" */
    "Options:	SEP\n"
    "Options:	Fonts Darker:		Alt-Ctrl-+:	change-density(25)\n"
    "Options:	Fonts Lighter:		Alt-Ctrl--:	change-density(-25)\n"
    "Help:	Introduction ...:	:		help(Introduction)\n"
    "Help:	Page Motion ...:	:		help(Page Motion)\n"
    "Help:	Other Commands ...:	:		help(Other Commands)\n"
    "Help:	Mouse Buttons ...:	:		help(Mouse Buttons)\n"
    "Help:	Hyperlinks ...:		:		help(Hyperlinks)\n"
    "Help:	Printing and Saving ...::		help(Printing and Saving)\n"
    "Help:	Source Specials ...:	:		help(Source Specials)\n"
    "Help:SEP\n"
    "Help:	New Features in this Version::	load-url(http\\://xdvi.sourceforge.net/releases/" XDVI_VERSION ".html)\n"
    "Help:	Send a Bug Report:	:		load-url(http\\://sourceforge.net/tracker/?func=add&group_id=23164&atid=377580)\n"
    "";


static _Xconst char default_toolbar_translations[] =
/*  index	statusline-text					tooltip		action */
    "SPACER(5)\n"
    "0:	Open a new document   (Key\\: Ctrl-f):			Open file:	select-dvi-file()\n"
    "SPACER(10)\n"
    "1:	Reread this document   (Key\\: R):			Reread file:	reread-dvi-file()\n"
    "SPACER(10)\n"
    "2:	Go to the first page of this document   (Key\\: 1g):	First page:	goto-page(1)\n"
    "3:	Go to the previous page of this document   (Key\\: p):	Previous page:	back-page(1)\n"
    "4:	Go to the next page of this document   (Key\\: n):	Next page:	forward-page(1)\n"
    "5:	Go to the last page of this document   (Key\\: g):	Last page:	goto-page(e)\n"
    "SPACER(10)\n"
    "6:	Enlarge the display   (Key\\: Ctrl-+):		Zoom in:		set-shrink-factor(+)\n"
    "7:	Shrink the display   (Key\\: Ctrl--):		Zoom out:		set-shrink-factor(-)\n"
    "SPACER(10)\n"
    "8:	Back to previous link in history   (Key\\: B):	Back hyperlink:		htex-back()\n"
    "9:	Forward to next link in history   (Key\\: F):	Forward hyperlink:	htex-forward()\n"
    "SPACER(10)\n"
    "11:Print this document:Print:print()\n"
    "SPACER(10)\n"
    "12:Toggle marks of odd pages   (Key\\: 1m):	Toggle odd pages:	toggle-mark(1)\n"
    "13:Toggle marks of even pages   (Key\\: 2m):	Toggle even pages:	toggle-mark(2)\n"
    "14:Toggle mark of current page   (Key\\: 2m):	Toggle current page:	toggle-mark()\n"
    "15:Unmark all pages   (Key\\: 0m):			Unmark all pages:	toggle-mark(0)\n"
    "SPACER(10)\n"
    "19:Display fonts darker   (Key\\: Alt-Ctrl-+):	Fonts darker:		change-density(5)\n"
    "20:Display fonts lighter   (Key\\: Alt-Ctrl--):	Fonts lighter:		change-density(-5)\n"
    "";
